<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleConcentricThrough</name>
    <message>
        <location filename="../CircleConcentricThrough.ui" line="+17"/>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation>Ilość:</translation>
    </message>
    <message>
        <location filename="../CircleConcentricThroughInit.js" line="+2"/>
        <source>Concentric (&amp;through Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Koncentryczny (przez p&amp;unkt)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw concentric circle through point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje koncentryczny okrąg przez punkt</translation>
    </message>
</context>
</TS>
